@@ -3,17 +3,16 @@
 
 from coinmarketcap_utils import coin_info
 from coinmarketcap_utils import update_info
+from coinmarketcap_utils import top_currencies
 from coinmarketcap_utils import market_cap_info
 from coinmarketcap_utils import coinmarketcap_info
 
-
 __title__   = 'coinmarketcap'
-__version__ = '0.6.1'
+__version__ = '0.7'
 __author__  = '@c0ding'
 __repo__    = 'https://github.com/c0ding/coinmarketcap-api'
 __license__ = 'Apache v2.0 License'
 
-
 def about():
 	"""Returns some information about the coinmarketcap module."""
 
@@ -60,6 +59,9 @@ def cap_change_7d(PARAMETER):
 	return coin_info(PARAMETER)[9]
 
 
+def top(PARAMETER):
+	return top_currencies(PARAMETER)
+
 def mineable(PARAMETER):
 	try:
 		if coin_info(PARAMETER)[10] == '*':
